@@ -467,6 +467,8 @@ is_tds_type_valid(int type)
 #define TDS_STR_READONLY_INTENT "read-only intent"
 /* configurable cipher suite to send to openssl's SSL_set_cipher_list() function */
 #define TLS_STR_OPENSSL_CIPHERS "openssl ciphers"
+/* configurable cipher suite to send to gnutls's gnutls_priority_set_direct() function */
+#define TLS_STR_GNUTLS_CIPHERS "gnutls ciphers"
 /* enable old TLS v1, required for instance if you are using a really old Windows XP */
 #define TDS_STR_ENABLE_TLS_V1 "enable tls v1"
 /* enable old TLS v1.1 */
@@ -514,6 +516,7 @@ typedef struct tds_login
 	DSTR crlfile;			/**< certificate revocation file */
 	DSTR certificate_host_name;	/**< certificate hostname to check, if empty use server_host_name */
 	DSTR openssl_ciphers;
+	DSTR gnutls_ciphers;		/**< gnutls ciphers to use */
 	DSTR app_name;
 	DSTR user_name;	    	/**< account for login */
 	DSTR password;	    	/**< password of account login */
@@ -1521,7 +1524,14 @@ void tdsdump_off(TDSDUMP_OFF_ITEM *off_item);
 void tdsdump_on(TDSDUMP_OFF_ITEM *off_item);
 int tdsdump_isopen(void);
 #include <freetds/popvis.h>
-int tdsdump_open(const tds_dir_char *filename);
+/* This function is exported by DB-Library, do not change its ABI */
+int tdsdump_open(const char *filename);
+#ifdef _WIN32
+int tdsdump_wopen(const wchar_t *filename);
+#define tdsdump_topen tdsdump_wopen
+#else
+#define tdsdump_topen tdsdump_open
+#endif
 #include <freetds/pushvis.h>
 void tdsdump_close(void);
 void tdsdump_dump_buf(const char* file, unsigned int level_line, const char *msg, const void *buf, size_t length);
